@@ -36,6 +36,7 @@ def getContentComponentDefaults(
         host,
         primary_btn=None,
         secondary_btn=None,
+        trinary_btn=None,
         default_allowed_exts_in=None,
         default_unallowed_exts_in=None,
         default_exclude_types_in=None,
@@ -44,10 +45,11 @@ def getContentComponentDefaults(
         add=False
     ):
     DEFAULT_SECONDARY_BUTTON=("blank", None) 
-    DEFAULT_PRIMARY_BUTTON = ("Run", None) 
+    DEFAULT_PRIMARY_BUTTON = ("Run", None)
+    DEFAULT_TRINARY_BUTTON = ("open all hits", host.open_all_hits)
     host.primary_btn=primary_btn or DEFAULT_PRIMARY_BUTTON
     host.secondary_btn=secondary_btn or  DEFAULT_SECONDARY_BUTTON
-    host.third_btn=("open all hits", host.open_all_hits)
+    host.trinary_btn = trinary_btn or  DEFAULT_TRINARY_BUTTON
     file_defaults = derive_file_defaults(
         allowed_exts=default_allowed_exts_in,
         unallowed_exts=default_unallowed_exts_in,
@@ -102,8 +104,8 @@ def createLayoutForm(host):
     if host.secondary_btn[1]:
         host.btn_secondary = QPushButton(host.secondary_btn[0]); host.btn_secondary.clicked.connect(host.secondary_btn[1])
         cta.addWidget(host.btn_secondary)
-    if host.third_btn[1]:
-        host.btn_third = QPushButton(host.third_btn[0]); host.btn_third.clicked.connect(host.third_btn[1])
+    if host.trinary_btn[1]:
+        host.btn_third = QPushButton(host.trinary_btn[0]); host.btn_third.clicked.connect(host.trinary_btn[1])
         cta.addWidget(host.btn_third)
     host.layout().addLayout(cta)
 def getSharedBus(host,bus=None,auto_unlink_on_init_if_diff=True,global_default_filters: dict | None = None):
@@ -193,6 +195,7 @@ def install_common_inputs(host, grid: QGridLayout, *,
                           bus: SharedStateBus,
                           primary_btn=None,
                           secondary_btn=None,
+                          trinary_btn=None,
                           default_dir_in=None,
                           default_allowed_exts_in=None,
                           default_unallowed_exts_in=None,
@@ -221,6 +224,7 @@ def install_common_inputs(host, grid: QGridLayout, *,
         host,
         primary_btn=primary_btn,
         secondary_btn=secondary_btn,
+        trinary_btn=trinary_btn,
         default_allowed_exts_in=default_allowed_exts_in,
         default_unallowed_exts_in=default_unallowed_exts_in,
         default_exclude_types_in=default_exclude_types_in,
